@@ -1,6 +1,6 @@
 package Enbld::Message;
 
-use 5.012;
+use strict;
 use warnings;
 
 our $VERBOSE;
