@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-use 5.012;
+use strict;
 use warnings;
 
 use utf8;
@@ -9,7 +9,7 @@ use lib "$ENV{HOME}/.enbld/extlib/lib/perl5/";
 
 use Enbld;
 
-enbld 'myenv' => build {
+enbld 'mydevenv' => build {
 
     target 'perl' => define {
         version '5.18.1';
